datablock PlayerData(SBBArmor : HorseArmor)
{
   shapeFile = "./SBB.dts";

   mass = 400;
   drag = 0.1;
   density = 0.7;
   maxDamage = 100;

   runForce = 60 * 90;
   maxForwardSpeed = 20;
   maxBackwardSpeed = 20;
   maxSideSpeed = 20;

   maxForwardCrouchSpeed = 20;
   maxBackwardCrouchSpeed = 20;
   maxSideCrouchSpeed = 20;

   maxUnderwaterForwardSpeed = 7.8;
   maxUnderwaterBackwardSpeed = 7.8;
   maxUnderwaterSideSpeed = 7.8;

   jumpForce = 0; //8.3 * 90;

   boundingBox			= vectorScale("3.6 3.6 3.6", 4);
   crouchBoundingBox	= vectorScale("3.6 3.6 3.6", 4);
   
   pickupRadius = 0.75;

   // Controls over slope of runnable/jumpable surfaces
   runSurfaceAngle  = 85;
   jumpSurfaceAngle = 86;

   minJumpSpeed = 0;
   maxJumpSpeed = 0;

   horizMaxSpeed = 68;
   horizResistSpeed = 33;
   horizResistFactor = 0.35;

   upMaxSpeed = 80;
   upResistSpeed = 25;
   upResistFactor = 0.3;

   // Inventory Items
	maxItems   = 10;	//total number of bricks you can carry
	maxWeapons = 5;		//this will be controlled by mini-game code
	maxTools = 5;
	
	uiName = "Super Blockey Ball";
	rideable = true;
		lookUpLimit = 0.6;
		lookDownLimit = 0.2;

	canRide = false;
	showEnergyBar = false;
	paintable = true;

	brickImage = SBBBrickImage;	//the imageData to use for brick deployment

   numMountPoints = 1;
   mountThread[0] = "root";
   mountNode[0] = 1;
};

function ShapeBase::isMovingLeft(%this,%tolerance)
{
        if(!%tolerance) //We can't have a tolerance of 0, because the angles might vary slightly due to rounding error
                %tolerance = 0.01;
               
        %movingVector = %this.getVelocity(); //The direction we're moving
        %movingX = getWord(%movingVector,0);
        %movingY = getWord(%movingVector,1);
       
        if(!VectorLen(%movingVector)) //We're not moving at all
                return 0;
       
        %leftVector = %this.getLeftFVector();
        %leftX = getWord(%leftVector,0);
        %leftY = getWord(%leftVector,1);
       
        %movingAngle = mRadToDeg(mATan(%movingX,%movingY));
        %leftAngle = mRadToDeg(mATan(%leftX,%leftY));
       
        if(mAbs(%movingAngle-%leftAngle) <= %tolerance)
                return 1;
        else
                return 0;
}
 
function ShapeBase::isMovingRight(%this,%tolerance)
{
        if(!%tolerance) //We can't have a tolerance of 0, because the angles might vary slightly due to rounding error
                %tolerance = 0.01;
               
        %movingVector = %this.getVelocity(); //The direction we're moving
        %movingX = getWord(%movingVector,0);
        %movingY = getWord(%movingVector,1);
       
        if(!VectorLen(%movingVector)) //We're not moving at all
                return 0;
 
        %rightVector = %this.getRightFVector();
        %rightX = getWord(%rightVector,0);
        %rightY = getWord(%rightVector,1);
       
        %movingAngle = mRadToDeg(mATan(%movingX,%movingY));
        %rightAngle = mRadToDeg(mATan(%rightX,%rightY));
       
        if(mAbs(%movingAngle-%rightAngle) <= %tolerance)
                return 1;
        else
                return 0;
}

function SBBArmor::onAdd(%this,%obj)
{
   // Vehicle timeout
   %obj.mountVehicle = true;

   // Default dynamic armor stats
   %obj.setRepairRate(0);

   // Start the speedcheck
   SBBSpeedCheck(%this, %obj);

   // Check if your moving left and right
   %this.moveCheckLoop(%obj);
}

//called when the driver of a player-vehicle is unmounted
function SBBArmor::onDriverLeave(%obj, %player)
{
	Cancel(%obj.sbbschedule);
}

function SBBSpeedCheck(%this, %obj)
{
   if(isObject(%obj))
   {
	  %speed = vectorLen(%obj.getVelocity());
	  %speed = mFloor(%speed);
	  %driver = %obj.getMountedObject(0);
   }
   
   if(isObject(%driver))
   {
      if(%speed > 1)
      {
         %driver.playThread(0, run);
      }
      else if(%speed < 1)
      {
         %driver.playThread(0, root);
      }
   }

	%obj.sbbschedule = Schedule(500, 0, SBBSpeedCheck, %this, %obj);
}

function SBBArmor::moveCheckLoop(%this,%obj)
{
        cancel(%obj.moveCheckTick);
   
        if(!isObject(%obj))
                        return;
       
        %left = %obj.isMovingLeft(15);
        if(%left && !%obj.isMovingLeft)
        {
                        %obj.isMovingLeft = 1;
                        %this.onMoveLeft(%obj);
        }
        else if(!%left && %obj.isMovingLeft)
        {
                        %obj.isMovingLeft = 0;
                        %this.onStopMoveLeft(%obj);
        }
   
        %right = %obj.isMovingRight(15);
        if(%right && !%obj.isMovingRight)
        {
                        %obj.isMovingRight = 1;
                        %this.onMoveRight(%obj);
        }
        else if(!%right && %obj.isMovingRight)
        {
                        %obj.isMovingRight = 0;
                        %this.onStopMoveRight(%obj);
        }
   
        %obj.moveCheckTick = %this.schedule(100,moveCheckLoop,%obj);
}
 
function SBBArmor::onMoveLeft(%this,%obj)
{
        %obj.playThread(0, left);
}
 
function SBBArmor::onStopMoveLeft(%this,%obj)
{
        %obj.playThread(0, root);
}
 
function SBBArmor::onMoveRight(%this,%obj)
{
        %obj.playThread(0, right);
}
 
function SBBArmor::onStopMoveRight(%this,%obj)
{
        %obj.playThread(0, root);
}